unit PrmptDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Registry, fmPrmptDlg;

type
  TImageType = (itError, itInfo, itConfirm, itWarning, itNone);

type
  TPrmptDlg = class(TComponent)
  private
    FConnected: Boolean;
    FMessage: String;
    FCaption: String;
    FImageType: TImageType;
    FHelpContext: THelpContext;
    procedure SetCaption(const Value: String);
    procedure SetConnected(const Value: Boolean);
    procedure SetImageType(const Value: TImageType);
    procedure SetKeyName(const Value: String);
    procedure SetMessage(const Value: String);
    procedure SetRegPath(const Value: String);
    procedure SetHelpContext(const Value: THelpContext);
    { Private declarations }
  protected
    { Protected declarations }
  public
    FRegPath: String;
    FKeyName: String;
    function Execute: TModalResult;
    procedure UpdateReg(Bool: Boolean);

  published
    Property Connected: Boolean read FConnected write SetConnected Default False;
    Property RegPath: String read FRegPath write SetRegPath;
    Property KeyName: String read FKeyName write SetKeyName;
    Property Caption: String read FCaption write SetCaption;
    Property UserMessage: String read FMessage write SetMessage;
    Property ImageType: TImageType read FImageType write SetImageType Default itError;
    Property HelpContext: THelpContext read FHelpContext write SetHelpContext;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('NSG', [TPrmptDlg]);
end;

function TPrmptDlg.Execute: TModalResult;
var
  aRegistry: TRegistry;
begin
  try
    frmPrmptDlg := TFrmPrmptDlg.Create(Application);
    aRegistry := TRegistry.create;
    aRegistry.RootKey := Hkey_Current_User;
    aRegistry.openKey(FRegPath, true);


    if FKeyName = '' then
      FKeyName := 'Connected';
    if aRegistry.ValueExists(FKeyName) = false then
      aRegistry.WriteBool(FKeyName, True);

    case Ord(FImageType) of
      0: frmPrmptDlg.Img1.Visible := True;
      1: frmPrmptDlg.Img2.Visible := True;
      2: frmPrmptDlg.Img3.Visible := True;
      3: frmPrmptDlg.Img4.Visible := True;
    end;

  frmPrmptDlg.Caption := FCaption;
  frmPrmptDlg.lblCaption.Caption := FMessage;
  frmPrmptDlg.HelpContext := FHelpContext;
  frmPrmptDlg.BitBtnHelp.HelpContext := FHelpContext;
  frmPrmptDlg.FRegPath := FRegPath;
  frmPrmptDlg.FKeyName := FKeyName;
  frmPrmptDlg.Icon := Application.Icon;

  if aRegistry.ReadBool(FKeyName) then
    Result := frmPrmptDlg.ShowModal
  else
    Result := mrNone;


  finally
    aRegistry.Free;
    aRegistry := nil;
    frmPrmptDlg.Free;
    frmPrmptDlg := nil;
  end;
end;

procedure TPrmptDlg.SetCaption(const Value: String);
begin
  FCaption := Value;
end;

procedure TPrmptDlg.SetConnected(const Value: Boolean);
begin
  FConnected := Value;
end;

procedure TPrmptDlg.SetHelpContext(const Value: THelpContext);
begin
  FHelpContext := Value;
end;

procedure TPrmptDlg.SetImageType(const Value: TImageType);
begin
  FImageType := Value;
end;

procedure TPrmptDlg.SetKeyName(const Value: String);
begin
  FKeyName := Value;
end;

procedure TPrmptDlg.SetMessage(const Value: String);
begin
  FMessage := Value;
end;

procedure TPrmptDlg.SetRegPath(const Value: String);
begin
  FRegPath := Value;
end;

procedure TPrmptDlg.UpdateReg(Bool: Boolean);
var
  aRegistry: TRegistry;
begin
  try
    aRegistry := TRegistry.Create;
    aRegistry.RootKey := Hkey_Current_User;
    aRegistry.OpenKey(FRegPath, true);
    aRegistry.WriteBool(FKeyName, Bool);
  finally
    aRegistry.Free;
    aRegistry := nil;
  end;
end;

end.
